import * as backup from '@aws-cdk/aws-backup';
import * as dynamodb from '@aws-cdk/aws-dynamodb';
import { Schedule } from '@aws-cdk/aws-events';
import * as cdk from '@aws-cdk/core';
/**
 * @stability stable
 */
export interface CompliantDynamoDbProps extends dynamodb.TableProps {
    /**
     * name of the backup vault.
     *
     * Can only contain letters, numbers and _,-
     *
     * @default - table name + '-backup-vault'
     * @stability stable
     */
    readonly backupVaultName?: string;
    /**
     * provide a cron schedule that sets the start time of the backup.
     *
     * @default Schedule - Schedule.cron({ hour: '21', minute: '0', }),
     * @stability stable
     */
    readonly backupPlanStartTime?: Schedule;
    /**
     * interface parameter description test.
     *
     * @default - dynamodb table default settings
     * @stability stable
     * @type {RULE_IDENTIFIER : boolean}
     */
    readonly configRuleList?: any;
}
/**
 * Creates a DynamoDB table that is secured by an AWS backup plan und with point in time recovery enabled by default.
 *
 * @stability stable
 */
export declare class CompliantDynamoDb extends cdk.Construct {
    /**
     * @stability stable
     */
    readonly dynamodbTable: dynamodb.Table;
    /**
     * @stability stable
     */
    readonly backupPlan: backup.BackupPlan;
    /**
     * @stability stable
     */
    readonly backupVault: backup.BackupVault;
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: CompliantDynamoDbProps);
}
